// Copyright (c) Mito
import React from 'react';
import '../../../css/text-button/text-button.css';
import { classNames } from '../../utils/classNames';
/**
 *
 * The TextButton component is a rectangular, colored button that contains centered text.
 *
 * By default, it relies on the HTML button, but if the href param is supplied, it will use
 * the anchor tag instead.
 *
 */
const TextButton = (props) => {
    // Create bette default values to handle optional params 
    const disabled = props.disabled === true;
    const autoFocus = props.autoFocus === true;
    const size = props.size || 'block';
    // Create css classes to apply
    const disabledClass = disabled ? 'text-button-disabled' : '';
    const sizeClass = `text-button-size-${size}`;
    const variantClass = `text-button-variant-${props.variant}`;
    if (props.href !== undefined) {
        return (React.createElement("a", { className: classNames('text-button', sizeClass, variantClass, disabledClass), 
            /*
                Because anchor tags don't handle the disabled keyword, we check that the element
                is not disabled before taking any action.
            */
            href: disabled ? undefined : props.href, download: disabled ? undefined : props.download, onClick: disabled ? () => { return; } : props.onClick, target: props.target }, props.children));
    }
    else {
        return (React.createElement("button", { className: classNames('text-button', sizeClass, variantClass, disabledClass), onClick: props.onClick, type: props.type, disabled: disabled, autoFocus: autoFocus }, props.children));
    }
};
export default TextButton;
//# sourceMappingURL=TextButton.js.map